'use strict';

var server = require('server');

server.extend(module.superModule);

server.append('SubmitPayment', function (req, res, next) {
    this.on('route:BeforeComplete', function (req, res) { // eslint-disable-line no-shadow
        var scalapayHelper = require('*/cartridge/scripts/helpers/scalapayHelper');
        var isScalaPayPaymentMethod = scalapayHelper.isScalaPayMethod();

        if (isScalaPayPaymentMethod && session.privacy.scalapayAuthURL) {
            var scalapayOrderToken = scalapayHelper.getPaymentToken(),
                viewData = res.getViewData(),
                billingData = res.getViewData(),
                paymentOptionID = session.forms.scalapaymentoptions.paymentoptions.htmlValue;

            if (!scalapayOrderToken) {
                var isScalapayApplicable = scalapayHelper.isPaymentApplicable(paymentOptionID);

                if (isScalapayApplicable) {
                    viewData.redirectURL = session.privacy.scalapayAuthURL;
                    res.json(viewData);
                    return;
                }
                session.privacy.scalapayAuthURL = null;
                var Resource = require('dw/web/Resource'),
                    paymentNotApplicable = {},
                    Logger = require('dw/system/Logger').getLogger('scalapay'),
                    billingForm = server.forms.getForm('billing');

                paymentNotApplicable[billingData.paymentMethod.htmlName] = Resource.msg('payment.not.applicable.error', 'payment', null);
                Logger.error('Scalapay payment authorization error. Error: Payment method is not applicable');

                res.json({
                    form: billingForm,
                    fieldErrors: [paymentNotApplicable],
                    serverErrors: [],
                    error: true
                });
                return;
            }
            var URLUtils = require('dw/web/URLUtils');
            viewData.redirectURL = URLUtils.https('Scalapay-HandlePayment', 'status', 'success', 'orderToken', scalapayOrderToken).toString();
            res.json(viewData);
            return;
        }
    });
    next();
});

server.append('PlaceOrder', function (req, res, next) {
    var scalapayHelper = require('*/cartridge/scripts/helpers/scalapayHelper'),
        OrderMgr = require('dw/order/OrderMgr'),
        viewData = res.getViewData(),
        orderID = viewData.orderID,
        isScalaPayPaymentMethod,
        order;

    if (orderID) {
        order = OrderMgr.getOrder(orderID);
        if (order) {
            isScalaPayPaymentMethod = scalapayHelper.isScalaPayMethod(order);
        }
    } else {
        isScalaPayPaymentMethod = scalapayHelper.isScalaPayMethod();
    }

    if (isScalaPayPaymentMethod) {
        var URLUtils = require('dw/web/URLUtils'),
            Site = require('dw/system/Site'),
            isSummaryPageStepEnabled = Site.getCurrent().getCustomPreferenceValue('scalapayEnableSummaryPage'),
            redirectUrl;

        if (viewData.error) {
            var Logger = require('dw/system/Logger').getLogger('scalapay'),
                errorMessage = '';

            if (!session.privacy.scalapayAuthURL) {
                var Resource = require('dw/web/Resource');

                Logger.error('Scalapay place Order error. Error: Payment authorization URL missed');
                errorMessage = Resource.msg('scalapay.errorpayment.error.002', 'scalapay', '');
            } else if (viewData.errorMessage) {
                errorMessage = viewData.errorMessage;
                Logger.error('Scalapay place Order error. Error: ' + viewData.errorMessage);
            }

            redirectUrl = viewData.redirectURL || URLUtils.https('Checkout-Begin', 'stage', 'payment', 'errorMessage', errorMessage).toString();

            if (order) {
                var Transaction = require('dw/system/Transaction');
                Transaction.wrap(function () {
                    OrderMgr.failOrder(order, true);
                });
            }
        } else if (order) {
            var orderToken = (viewData.orderToken || '');
            redirectUrl = URLUtils.url('Order-Confirm', 'ID', orderID, 'token', orderToken).toString();
        }

        if (viewData.error) {
            if (isSummaryPageStepEnabled) {
                res.json({
                    redirectUrl: redirectUrl,
                    error: true,
                    cartError: true
                });
            } else {
                res.redirect(redirectUrl);
            }
        } else {
            if (!isSummaryPageStepEnabled && redirectUrl) { // eslint-disable-line no-lonely-if
                res.redirect(redirectUrl);
            }
        }
    }

    return next();
});
module.exports = server.exports();
