'use strict';

var server = require('server');

server.get('HandlePayment', function (req, res, next) { // eslint-disable-line no-unused-vars
    var URLUtils = require('dw/web/URLUtils'),
        Logger = require('dw/system/Logger').getLogger('scalapay'),
        httpParams = req.querystring,
        orderToken = httpParams.orderToken,
        status = httpParams.status;

    if (!session.privacy.scalapayAuthURL) {
        Logger.error('Scalapay payment authorization error. Error: Payment authorization URL missed');
        res.redirect(URLUtils.https('Cart-Show').toString());
    } else if (orderToken && status.toLowerCase() === 'success') {
        var scalapayHelper = require('*/cartridge/scripts/helpers/scalapayHelper'),
            Site = require('dw/system/Site'),
            isSummaryPageStepEnabled = Site.getCurrent().getCustomPreferenceValue('scalapayEnableSummaryPage');

        scalapayHelper.updatePaymentToken(orderToken);
        if (isSummaryPageStepEnabled) {
            response.redirect(URLUtils.https('Checkout-Begin', 'stage', 'placeOrder').toString());
            return; // eslint-disable-line
        } else {
            res.render('checkout/payment/submitorder', {
                submitOrderURL: URLUtils.https('CheckoutServices-PlaceOrder')
            });
        }
    } else {
        if (session.privacy.scalapayAuthURL) {
            delete session.privacy.scalapayAuthURL;
        }
        var Resource = require('dw/web/Resource'),
            errorMessage = Resource.msg('scalapay.errorpayment.error.001', 'scalapay', '');

        Logger.error('Scalapay payment authorization error. Error: Payment authorization rejected');
        res.redirect(URLUtils.https('Checkout-Begin', 'stage', 'payment', 'errorMessage', errorMessage).toString());
    }
    return next(); // eslint-disable-line
});

server.get('ShowWidget', function (req, res, next) {
    var scalaPayHelper = require('*/cartridge/scripts/helpers/scalapayHelper'),
        isScalaPayEnabled = scalaPayHelper.isEnabled(),
        httpParams = req.querystring,
        scalapayWidgetData;

    if (isScalaPayEnabled) {
        var scalaPayWidgetHelper = require('*/cartridge/scripts/helpers/scalaPayWidgetHelper');
        scalapayWidgetData = scalaPayWidgetHelper.setWidgetType(httpParams.wtype).getWidgetData({
            type: httpParams.type,
            pid: httpParams.pid
        });
    }
    res.render('scalapay/scalapaywidget', {
        widgetSettings: scalapayWidgetData
    });
    next();
});

module.exports = server.exports();
