'use strict';

var ScalaPayWidgetHelper = {
    setWidgetType: function (widgetType) {
        this.paymentWidgetType = widgetType;
        return this;
    },
    paymentWidgetType: '',
    getWidgetType: function () {
        return this.paymentWidgetType;
    },
    getWidgetData: function (parametersObj) {
        var pageType = parametersObj.type,
            widgetData;

        if (pageType) {
            if (pageType === 'product' && parametersObj.pid) {
                widgetData = this.getProductEligibilityData(parametersObj.pid);
            } else if (pageType === 'cart') {
                widgetData = this.getCartEligibilityData(parametersObj.basket);
            }
        }
        return widgetData;
    },
    getCartEligibilityData: function (lineItemContainer) {
        if (!lineItemContainer) {
            var BasketMgr = require('dw/order/BasketMgr');
            lineItemContainer = BasketMgr.getCurrentOrNewBasket();
        }
        var scalapayUtils = require('*/cartridge/scripts/helpers/scalapayUtils'),
            cartWidgetData,
            priceTotal = scalapayUtils.getNonGiftCertificateAmount(lineItemContainer);

        if (priceTotal && priceTotal.value) {
            var scalaPayHelper = require('*/cartridge/scripts/helpers/scalapayHelper'),
                self = this,
                widgetType = ScalaPayWidgetHelper.getWidgetType(),
                scalapaySettings = scalaPayHelper.getScalaPayOptionSettings(priceTotal.value, 'cart', widgetType);

            cartWidgetData = {
                display: scalapaySettings.isEligible,
                priceVal: priceTotal.value,
                minPriceVal: scalapaySettings.min,
                maxPriceVal: scalapaySettings.max,
                numberOfPayments: scalapaySettings.numberOfPayments,
                renderingSettings: self.getWidgetRenderSettings('cart', widgetType)
            };
        }
        return cartWidgetData;
    },
    getProductEligibilityData: function (pid) {
        var priceFactory = require('*/cartridge/scripts/factories/price'),
            apiProduct = require('dw/catalog/ProductMgr').getProduct(pid),
            productWidgetData,
            productPricing = priceFactory.getPrice(apiProduct);

        if (productPricing && (productPricing.sales || productPricing.min)) {
            var scalaPayHelper = require('*/cartridge/scripts/helpers/scalapayHelper'),
                isProductCategoryEligible = scalaPayHelper.isProductCategoryEligible(apiProduct);

            if (isProductCategoryEligible) {
                var productPrice = productPricing.sales ? productPricing.sales.value : productPricing.min.sales.value,
                    self = this,
                    widgetType = ScalaPayWidgetHelper.getWidgetType(),
                    scalapaySettings = scalaPayHelper.getScalaPayOptionSettings(productPrice, 'product', widgetType);

                productWidgetData = {
                    display: scalapaySettings.isEligible,
                    priceVal: productPrice,
                    minPriceVal: scalapaySettings.min,
                    maxPriceVal: scalapaySettings.max,
                    numberOfPayments: scalapaySettings.numberOfPayments,
                    renderingSettings: self.getWidgetRenderSettings('product', widgetType)
                };
            }
        }
        return productWidgetData;
    },
    getWidgetRenderSettings: function (pageType, widgetType) {
        pageType = pageType || 'product';
        var currentSite = require('dw/system/Site').getCurrent(),
            scalaPayHelper = require('*/cartridge/scripts/helpers/scalapayHelper'),
            settingsMapping = scalaPayHelper.getSettingsMapping(),
            defaultLocale = 'en',
            requestLocale = request.locale.split('_'),
            widgetLocale = requestLocale.length > 1 ? requestLocale[0] : defaultLocale,
            redneringSettings = {
                locale: widgetLocale
            };

        // pay in 3 and pay in 4 settings
        if (widgetType != 'pl') {
            redneringSettings.logoSize = currentSite.getCustomPreferenceValue(settingsMapping[pageType][widgetType].logoSize);
            redneringSettings.currencyPos = currentSite.getCustomPreferenceValue(settingsMapping.general.global.currencyPos).value;
            redneringSettings.currencyDisplay = currentSite.getCustomPreferenceValue(settingsMapping.general.global.currencyDisplay).value;
            redneringSettings.hidePrice = currentSite.getCustomPreferenceValue(settingsMapping[pageType][widgetType].hidePrice);
            redneringSettings.frequency = currentSite.getCustomPreferenceValue(settingsMapping.general[widgetType].frequency).value;
        } else {
            // pay later settings
            redneringSettings.frequency = currentSite.getCustomPreferenceValue(settingsMapping.general[widgetType].frequency);
        }

        redneringSettings.priceBoxSelector = currentSite.getCustomPreferenceValue(settingsMapping[pageType].global.priceSelector);
        redneringSettings.installmentsNumber = currentSite.getCustomPreferenceValue(settingsMapping.general[widgetType].installmentsNumber).value;
        redneringSettings.theme = currentSite.getCustomPreferenceValue(settingsMapping.general.global.theme).value;

        return redneringSettings;
    }
};

module.exports = ScalaPayWidgetHelper;
